---
title: <span class="badge object-type-scalar"></span> MegaWattHour
---
# <span class="badge object-type-scalar"></span> MegaWattHour

Energy: Megawatt-hour (MWh)

## Definition

```python
# Energy: Megawatt-hour (MWh)
MegaWattHour: typing.Literal["mwatth"] = "mwatth"
```
